;; Generated package description from pinentry.el  -*- no-byte-compile: t -*-
(define-package "pinentry" "0.1.0.20241122.13623" "GnuPG Pinentry server implementation" 'nil :commit "bee37d95fbd080959cd0859b66227390265de3b4" :authors '(("Daiki Ueno" . "ueno@gnu.org")) :maintainer '("Daiki Ueno" . "ueno@gnu.org") :keywords '("gnupg") :url "https://github.com/ueno/pinentry-el")
